@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 
 use base 'Mutex';
 use Mutex::Util ();
@@ -87,7 +87,10 @@ sub synchronize {
     sysread($obj->{_r_sock}, my($b), 1), $obj->{ $pid } = 1
         unless $obj->{ $pid };
 
-    (defined wantarray) ? @ret = $code->(@_) : $code->(@_);
+    (defined wantarray)
+      ? @ret = wantarray ? $code->(@_) : scalar $code->(@_)
+      : $code->(@_);
+
     syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0;
 
     return wantarray ? @ret : $ret[-1];
@@ -111,7 +114,7 @@ Mutex::Channel - Mutex locking via a pipe or socket
 
 =head1 VERSION
 
-This document describes Mutex::Channel version 1.004
+This document describes Mutex::Channel version 1.005
 
 =head1 DESCRIPTION
 
